from stfdigital import __version__

from collections import OrderedDict

import setuptools


with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="api-stfdigital",
    version=f"{__version__}",
    author="alexandre menezes",
    author_email="alexandre.fmenezes@gmail.com",
    description="A pythonic wrapper for STF Digital",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="Apache-2.0",
    url="https://github.com/amenezes/api-stfdigital",
    packages=setuptools.find_packages(include=["stfdigital", "stfdigital.*"]),
    python_requires=">=3.6.0",
    project_urls=OrderedDict(
        (
            ("Documentation", "https://supremotribunalfederal.gitlab.io"),
            ("Code", "https://github.com/amenezes/api-stfdigital"),
            ("Issue tracker", "https://github.com/amenezes/api-stfdigital"),
        )
    ),
    install_requires=["aiohttp>=3.5.2", "discovery-client>=1.0.0a4"],
    tests_require=[
        "pytest",
        "pytest-cov",
        "pytest-mock",
        "flake8",
        "flake8-blind-except",
        "isort",
        "black",
        "mypy",
        "tox",
        "tox-asdf"
    ],
    extras_require={
        "cli": ["cleo>=0.7.6", "python-dotenv>=0.10.3"],
        "docs": ["portray"],
        "all": ["cleo>=0.7.6", "python-dotenv>=0.10.3", "portray"],
    },
    setup_requires=["setuptools>=38.6.0"],
    entry_points={"console_scripts": ["config=stfdigital.__main__:application.run [cli]"]},
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Framework :: AsyncIO",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Software Development :: Libraries",
    ],
)
