import tempfile
from contextlib import asynccontextmanager
from typing import AsyncIterator

from stfdigital.contexto import Contexto


class APPecas:
    CONTEXTO = Contexto.AP_PECAS

    def __init__(self, api):
        self._api = api

    async def pecas_processo(self, codigo: str) -> list:
        resp = await self._api.get(self.CONTEXTO, f"/api/processos/{codigo}/pecas")
        json_response: dict = await resp.json()
        return list(json_response["pecas"])

    @asynccontextmanager
    async def conteudo_peca(
        self,
        id_peca: int,
        chunk_size=10
        # ) -> AsyncIterator[IO[bytes]]:
    ) -> AsyncIterator[bytes]:
        response = await self._api.get(
            self.CONTEXTO, f"/api/conteudos/{id_peca}/binario"
        )
        tmp_file = tempfile.NamedTemporaryFile(mode="w+b")
        while True:
            chunk = await response.content(chunk_size)
            if not chunk:
                break
            tmp_file.write(chunk)
        try:
            tmp_file.seek(0)
            # yield memoryview(tmp_file.read())
            yield tmp_file.read()
            # yield tmp_file
        finally:
            tmp_file.close()
