import asyncio
from typing import Optional

from aiohttp import ClientSession

from stfdigital.http.base import Engine
from stfdigital.http.response import HTTPResponse


class AIOHTTPEngine(Engine):
    def __init__(self, session: Optional[ClientSession] = None):
        self._session = session or ClientSession()

    async def get(self, *args, **kwargs) -> HTTPResponse:
        resp = await self._session.get(*args, **kwargs)
        return HTTPResponse(resp)

    async def put(self, *args, **kwargs) -> HTTPResponse:
        resp = await self._session.put(*args, **kwargs)
        return HTTPResponse(resp)

    async def delete(self, *args, **kwargs) -> HTTPResponse:
        resp = await self._session.delete(*args, **kwargs)
        return HTTPResponse(resp)

    async def post(self, *args, **kwargs) -> HTTPResponse:
        resp = await self._session.post(*args, **kwargs)
        return HTTPResponse(resp)

    def _loop(self):
        try:
            loop = asyncio.get_running_loop()
        except RuntimeError:
            loop = asyncio.get_event_loop()
        return loop

    def __del__(self) -> None:
        if not self._session.closed:
            self._loop().run_until_complete(asyncio.shield(self._session.close()))
